==> accounts_management-0.1.6.gem: app/controllers/accounts_management/documents/contracts_controller.rb <==
require_dependency "accounts_management/accounts_management_controller"

module AccountsManagement
  class Documents::ContractsController < AccountsManagementController
    # GET /documents/contracts
    # GET /documents/contracts.json
    def index
      @documents_contracts = Documents::Contract.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @documents_contracts }
      end
    end

    # GET /documents/contracts/1
    # GET /documents/contracts/1.json
    def show
      @documents_contract = Documents::Contract.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @documents_contract }
      end
    end

    # GET /documents/contracts/new
    # GET /documents/contracts/new.json
    def new
      @documents_contract = Documents::Contract.new
      @documents_contract.contract_attachments.build
      @documents_contract.contract_attachments.each do |contract_attachment|
        contract_attachment.build_attachment
      end

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @documents_contract }
      end
    end

    # GET /documents/contracts/1/edit
    def edit
      @documents_contract = Documents::Contract.find(params[:id])

      if @documents_contract.contract_attachments.nil?
        @documents_contract.contract_attachments.build
        @documents_contract.contract_attachments.each do |contract_attachment|
          contract_attachment.build_attachment
        end
      end
    end

    # POST /documents/contracts
    # POST /documents/contracts.json
    def create
      @documents_contract = Documents::Contract.new(params[:documents_contract])

      respond_to do |format|
        if @documents_contract.save
          format.html { redirect_to @documents_contract, :notice => 'Contract was successfully created.' }
          format.json { render :json => @documents_contract, :status => :created, :location => @documents_contract }
        else
          format.html { render :action => "new" }
          format.json { render :json => @documents_contract.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /documents/contracts/1
    # PUT /documents/contracts/1.json
    def update
      @documents_contract = Documents::Contract.find(params[:id])

      respond_to do |format|
        if @documents_contract.update_attributes(params[:documents_contract])
          format.html { redirect_to @documents_contract, :notice => 'Contract was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @documents_contract.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /documents/contracts/1
    # DELETE /documents/contracts/1.json
    def destroy
      @documents_contract = Documents::Contract.find(params[:id])
      @documents_contract.destroy

      respond_to do |format|
        format.html { redirect_to documents_contracts_url }
        format.json { head :no_content }
      end
    end
  end
end

==> accounts_management-0.1.7.gem: app/controllers/accounts_management/documents/contracts_controller.rb <==
require_dependency "accounts_management/accounts_management_controller"

module AccountsManagement
  class Documents::ContractsController < AccountsManagementController
    # GET /documents/contracts
    # GET /documents/contracts.json
    def index
      @documents_contracts = Documents::Contract.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render json: @documents_contracts }
      end
    end

    # GET /documents/contracts/1
    # GET /documents/contracts/1.json
    def show
      @documents_contract = Documents::Contract.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render json: @documents_contract }
      end
    end

    # GET /documents/contracts/new
    # GET /documents/contracts/new.json
    def new
      @documents_contract = Documents::Contract.new
      @documents_contract.contract_attachments.build
      @documents_contract.contract_attachments.each do |contract_attachment|
        contract_attachment.build_attachment
      end

      respond_to do |format|
        format.html # new.html.erb
        format.json { render json: @documents_contract }
      end
    end

    # GET /documents/contracts/1/edit
    def edit
      @documents_contract = Documents::Contract.find(params[:id])

      return unless @documents_contract.contract_attachments.nil?

      @documents_contract.contract_attachments.build
      @documents_contract.contract_attachments.each do |contract_attachment|
        contract_attachment.build_attachment
      end
    end

    # POST /documents/contracts
    # POST /documents/contracts.json
    def create
      @documents_contract = Documents::Contract.new(params[:documents_contract])

      respond_to do |format|
        if @documents_contract.save
          format.html { redirect_to @documents_contract, notice: 'Contract was successfully created.' }
          format.json { render json: @documents_contract, status: :created, location: @documents_contract }
        else
          format.html { render action: "new" }
          format.json { render json: @documents_contract.errors, status: :unprocessable_entity }
        end
      end
    end

    # PUT /documents/contracts/1
    # PUT /documents/contracts/1.json
    def update
      @documents_contract = Documents::Contract.find(params[:id])

      respond_to do |format|
        if @documents_contract.update_attributes(params[:documents_contract])
          format.html { redirect_to @documents_contract, notice: 'Contract was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render action: "edit" }
          format.json { render json: @documents_contract.errors, status: :unprocessable_entity }
        end
      end
    end

    # DELETE /documents/contracts/1
    # DELETE /documents/contracts/1.json
    def destroy
      @documents_contract = Documents::Contract.find(params[:id])
      @documents_contract.destroy

      respond_to do |format|
        format.html { redirect_to documents_contracts_url }
        format.json { head :no_content }
      end
    end
  end
end
